@@ -296,6 +296,7 @@ segneigh.var.norm=function(data,Q=5,pen=0,know.mean=FALSE,mu=NA){
 
     op.cps=c(op.cps,which(criterion==min(criterion,na.rm=T))-1)
   }
+  if(op.cps==(Q-1)){warning('The number of segments identified is Q, it is advised to increase Q to make sure changepoints have not been missed.')}
   return(list(cps=cps.Q,op.cpts=op.cps,pen=pen,like=criterion[op.cps+1]))
 }
 
@@ -345,6 +346,7 @@ segneigh.mean.norm=function(data,Q=5,pen=0){
 
     op.cps=c(op.cps,which(criterion==min(criterion,na.rm=T))-1)
   }
+  if(op.cps==(Q-1)){warning('The number of segments identified is Q, it is advised to increase Q to make sure changepoints have not been missed.')}
   return(list(cps=cps.Q,op.cpts=op.cps,pen=pen,like=criterion[op.cps+1]))
 }
 
@@ -398,6 +400,7 @@ segneigh.meanvar.norm=function(data,Q=5,pen=0){
 
     op.cps=c(op.cps,which(criterion==min(criterion,na.rm=T))-1)
   }
+  if(op.cps==(Q-1)){warning('The number of segments identified is Q, it is advised to increase Q to make sure changepoints have not been missed.')}
   return(list(cps=cps.Q,op.cpts=op.cps,pen=pen,like=criterion[op.cps+1]))
 }
 
@@ -467,6 +470,7 @@ binseg.var.norm=function(data,Q=5,pen=0,know.mean=FALSE,mu=NA){
   op_cps=0
   
   answer=.C('binseg_var_norm',y2,as.integer(n),as.double(pen),as.integer(Q),as.integer(cptsout),likeout,as.integer(op_cps),PACKAGE='changepoint')
+  if(answer[[7]]==Q){warning('The number of changepoints identified is Q, it is advised to increase Q to make sure changepoints have not been missed.')}
   return(list(cps=rbind(answer[[5]],answer[[6]]),op.cpts=answer[[7]],pen=pen))
 }
 
@@ -530,6 +534,7 @@ binseg.mean.norm=function(data,Q=5,pen=0){
   op_cps=0
   
   answer=.C('binseg_mean_norm',y2,y,as.integer(n),as.double(pen),as.integer(Q),as.integer(cptsout),likeout,as.integer(op_cps),PACKAGE='changepoint')
+  if(answer[[8]]==Q){warning('The number of changepoints identified is Q, it is advised to increase Q to make sure changepoints have not been missed.')}
   return(list(cps=rbind(answer[[6]],answer[[7]]),op.cpts=answer[[8]],pen=pen))
 }
 
@@ -600,6 +605,7 @@ binseg.meanvar.norm=function(data,Q=5,pen=0){
   op_cps=0
   
   answer=.C('binseg_meanvar_norm',y2,y,as.integer(n),as.double(pen),as.integer(Q),as.integer(cptsout),likeout,as.integer(op_cps),PACKAGE='changepoint')
+  if(answer[[8]]==Q){warning('The number of changepoints identified is Q, it is advised to increase Q to make sure changepoints have not been missed.')}
   return(list(cps=rbind(answer[[6]],answer[[7]]),op.cpts=answer[[8]],pen=pen))
 }
 
