@@ -185,6 +185,7 @@ segneigh.meanvar.poisson=function(data,Q=5,pen=0){
     
     op.cps=c(op.cps,which(criterion==min(criterion,na.rm=T))-1)
   }
+  if(op.cps==(Q-1)){warning('The number of segments identified is Q, it is advised to increase Q to make sure changepoints have not been missed.')}
   return(list(cps=cps.Q,op.cpts=op.cps,pen=pen,like=criterion[op.cps+1]))
 }
 
@@ -207,6 +208,7 @@ binseg.meanvar.poisson=function(data,Q=5,pen=0){
   op_cps=0
   
   answer=.C('binseg_meanvar_poisson',y,as.integer(n),as.double(pen),as.integer(Q),as.integer(cptsout),likeout,as.integer(op_cps),PACKAGE='changepoint')
+  if(answer[[7]]==Q){warning('The number of changepoints identified is Q, it is advised to increase Q to make sure changepoints have not been missed.')}
   return(list(cps=rbind(answer[[5]],answer[[6]]),op.cpts=answer[[7]],pen=pen))
 }
 
